@@ -11,7 +11,6 @@ use RDF::Generator::Void::Stats;
 # use less ();
 use utf8;
 use URI::Split qw(uri_split uri_join);
-use Progress::Any;
 
 use aliased 'RDF::Generator::Void::Meta::Attribute::ObjectList';
 
@@ -28,11 +27,11 @@ RDF::Generator::Void - Generate VoID descriptions based on data in an RDF model
 
 =head1 VERSION
 
-Version 0.13_1
+Version 0.15_1
 
 =cut
 
-our $VERSION = '0.13_1';
+our $VERSION = '0.15_1';
 
 =head1 SYNOPSIS
 
@@ -101,9 +100,6 @@ has dataset_uri => (
 						  coerce   => 1,
 						 );
 
-our $progress; # Declared for everything in here
-
-
 # This will create a URN with a UUID by default
 sub _build_dataset_uri {
 	my ($self) = @_;
@@ -235,14 +231,7 @@ a model, one will be created for you.
 sub generate {
 	my $self = shift;
 	my $void_model = shift || RDF::Trine::Model->temporary_model;
-	local $progress = Progress::Any->get_indicator(task => "compute");
-	$progress->pos(0);
-	my $target_size = 11;
-	if ($self->has_level && ($self->level > 0)) {
-		$target_size += $self->inmodel->size;
-	}
-	$progress->target($target_size);
-	$progress->update(message => "Adding base statements");
+
 	local $self->{void_model} = $void_model;
 
 	# Start generating the actual VoID statements
@@ -251,7 +240,6 @@ sub generate {
 													 $rdf->type,
 													 $void->Dataset,
 													));
-	$progress->update(message => "Adding base statements");
 
 	my ($scheme, $auth, $path, $query, $frag) = uri_split($self->dataset_uri->uri_value);
 	if ($frag) { # Then, we have a document that could be described with provenance
@@ -271,9 +259,9 @@ sub generate {
 		$void_model->add_statement(statement($release_uri,
 														 iri('http://www.w3.org/2000/01/rdf-schema#label'),
 													    literal("RDF::Generator::Void, Version $VERSION", 'en')));
-		$progress->update(message => "Adding provenance statements");
 	}
 
+
 	foreach my $endpoint ($self->all_endpoints) {
 		$void_model->add_statement(statement(
 														 $self->dataset_uri,
@@ -298,7 +286,6 @@ sub generate {
 														));
 	}
 
-	$progress->update(message => "Adding user-set statements");
 
 	$void_model->add_statement(statement(
 													 $self->dataset_uri,
@@ -306,7 +293,6 @@ sub generate {
 													 literal($self->inmodel->size, undef, $xsd->integer),
 													));
 
-	$progress->update(message => "Adding base statements");
 	if ($self->has_urispace) {
 		$void_model->add_statement(statement(
 														 $self->dataset_uri,
@@ -317,7 +303,6 @@ sub generate {
 		$self->_generate_counts($void->entities, $self->stats->entities);
 	}
 
-
 	return $void_model if ($self->has_level && $self->level == 0);
 	$self->_generate_counts($void->distinctSubjects, $self->stats->subjects);
 	$self->_generate_counts($void->properties, $self->stats->properties);
@@ -327,14 +312,8 @@ sub generate {
 
 	return $void_model if ($self->has_level && $self->level <= 1);
 
-	$target_size += scalar(keys(%{$self->stats->propertyPartitions}));
-	$target_size += scalar(keys(%{$self->stats->classPartitions}));
-	$progress->target($target_size);
-
 	$self->_generate_propertypartitions;
 	$self->_generate_classpartitions;
-	$progress->update(message => "Finishing"); 
-
 	return $void_model;
 }
 
@@ -346,7 +325,6 @@ sub _generate_counts {
 																$predicate,
 																literal($count, undef, $xsd->integer),
 															  ));
-	$progress->update(message => "Adding counts statements");
 }
 
 sub _generate_propertypartitions {
@@ -375,7 +353,7 @@ sub _generate_propertypartitions {
 						 literal(scalar keys %{$counts->{'countobjects'}}, undef, $xsd->integer)));
 	 }
 
-	 $progress->update(message => "Adding property partition statements"); 
+		 
 
   }
 }
@@ -396,7 +374,6 @@ sub _generate_classpartitions {
     $self->{void_model}->add_statement(statement($blank,
 						 $void->triples,
 						 literal($count, undef, $xsd->integer)));
-	 $progress->update(message => "Adding class partition statements"); 
   }
 }
 
@@ -417,8 +394,6 @@ sub _generate_most_common_vocabs {
 																	iri($vocab),
 																  ));
 	}
-	$progress->update(message => "Adding vocabulary statements"); 
-	
 }
 
 
@@ -505,7 +480,7 @@ Many thanks to Konstantin Baierer for help with L<RDF::Generator::Void::Meta::At
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2012 Toby Inkster.
-Copyright 2012-2013 Kjetil Kjernsmo.
+Copyright 2012,2013,2016 Kjetil Kjernsmo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
